@@ -11,9 +11,10 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
     $|++;
 
     sub configure {
-        my ($self) = @_;
+        my ($self, @args) = @_;
         $self->quiet(1);
-        $self->SUPER::configure();
+        $self->SUPER::configure()
+            if !grep {m[no_base]} @args;    # Get basic config data
         $self->notes(  ldflags => ' -mwindows '
                      . $self->notes('ldflags')
                      . ' -lmsimg32 -lole32 -luuid -lcomctl32 -lwsock32');
@@ -26,6 +27,7 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
         #$self->notes('define')->{'HAVE_NDIR_H'}     = undef;
         $self->notes('define')->{'HAVE_SCANDIR'} = undef;
     GL: {
+            last if grep {m[^no_gl$]} @args;
             last GL if !$self->find_h('GL/gl.h');
             print 'Testing GL Support... ';
             if (!$self->assert_lib({lib => 'opengl32', header => 'GL/gl.h'}))
